@@ -1,6 +1,6 @@
-# $Id: File.pm,v 1.3 2002/04/03 21:33:06 cosimo Exp $
+# $Id: File.pm,v 1.4 2002/04/09 22:18:17 cosimo Exp $
 package Device::Modem::Log::File;
-$VERSION = substr q$Revision: 1.3 $, 10;
+$VERSION = substr q$Revision: 1.4 $, 10;
 
 use strict;
 use warnings;
@@ -71,9 +71,14 @@ None
 
 Cosimo Streppone, cosimo@cpan.org 
 
+=head1 COPYRIGHT
+
+This library is free software; you can only redistribute it and/or
+modify it under the same terms as Perl itself.
+
 =head1 SEE ALSO
 
-Device::Modem
-Device::Modem::Log::Syslog
+L<Device::Modem>
+L<Device::Modem::Log::Syslog>
 
 =cut
